# 15 Mar 2010, generate quarterly distributions of Afg/Pak violent events
#	for three categories: foreign forces, local forces, and insurgents
#
##########################################################################
# INSTRUCTIONS: set directories prior to analysis!
setwd('C:/Users/???/ACLEDevents')

afpak<-read.csv("afpak24may10_3actors.csv", as.is = TRUE)

names(afpak)
length(afpak$EVENT_ID)

# convert text date to a POSIXlt object
#afpak$EVENT_DATE[1:10]
	# %Y = year with century, %y = 2 digit year
dates<-strptime(afpak$EVENT_DATE, "%m/%d/%Y")
#summary(dates)

numMonths<-max(afpak$monthID)
numQuarters<-max(afpak$qtrID)
qtrLabels<-data.frame(table(afpak$qtrLbl))

############# subset 3 actor categories
forgn_evts<-afpak[afpak$forgn==1,]
gov_evts<-afpak[afpak$localGov==1,]
insgt_evts<-afpak[afpak$insgt==1,]

# check actor categories
length(forgn_evts$EVENT_ID)
length(gov_evts$EVENT_ID)
length(insgt_evts$EVENT_ID)
print(paste("total events = ", length(afpak$EVENT_ID), sep=""))
print(paste("should equal...", length(forgn_evts$EVENT_ID)+length(gov_evts$EVENT_ID)+length(insgt_evts$EVENT_ID), sep=""))


############# categorize by country
pak_forgn<-forgn_evts[forgn_evts$COUNTRY=="Pakistan", ]
pak_gov<-gov_evts[gov_evts$COUNTRY=="Pakistan", ]
pak_insgt<-insgt_evts[insgt_evts$COUNTRY=="Pakistan", ]
print(paste("total Pak events = ", length(afpak$EVENT_ID[afpak$COUNTRY=="Pakistan"]), sep=""))
print(paste("should equal...    ", length(pak_forgn$EVENT_ID)+length(pak_gov$EVENT_ID)+length(pak_insgt$EVENT_ID), sep=""))

afg_forgn<-forgn_evts[forgn_evts$COUNTRY=="Afghanistan", ]
afg_gov<-gov_evts[gov_evts$COUNTRY=="Afghanistan", ]
afg_insgt<-insgt_evts[insgt_evts$COUNTRY=="Afghanistan", ]
print(paste("total Afg events = ", length(afpak$EVENT_ID[afpak$COUNTRY=="Afghanistan"]), sep=""))
print(paste("should equal...    ", length(afg_forgn$EVENT_ID)+length(afg_gov$EVENT_ID)+length(afg_insgt$EVENT_ID), sep=""))

#*********************************************************************************
# function to aggregate events by quarter
#	requires events$qtrID to be set properly
#	requires events$FREQ to be set properly
# 	returns a data frame with the quarter ID & counts
quarterAgg <- function(events, numQtrs) {
	# aggregate events, making sure not to skip any 'empty' months!
	qCounts <- numeric(numQtrs)
	tmp <- data.frame(aggregate(events$FREQ, list(quarter = events$qtrID), sum))
	qCounts[tmp$quarter] <- tmp$x
	qCounts <- data.frame(qCounts)
	colnames(qCounts) <- "counts"
	return(qCounts)
}

# INSTRUCTIONS: set directories prior to analysis!
setwd('C:/Users/???/ActorTrends/')
clrs<-c("#E64C00FF", "#267300FF", "#6699CDFF")
commonYlim <- 270

# Afghanistan graph/data
qAfg <- cbind(qtrLabels$Var1, quarterAgg(afg_forgn, numQuarters), quarterAgg(afg_gov, numQuarters), quarterAgg(afg_insgt, numQuarters))
colnames(qAfg) <- c("Label", "AfgForgn", "AfgGov", "AfgInsgt")
write.csv(qAfg, "qtrAfg.csv", row.names=FALSE)
pdf("qtrAfg.pdf", height=6, width=10)
barplot(t(as.matrix(qAfg[,2:4])), main="Afghanistan violence by actor", cex.main=1.5, cex.lab=1.3, cex=1.2, cex.axis=1.2, ylab="Total number of events", ylim=c(0, commonYlim), names.arg=qAfg$Label, beside=T, col=clrs)
lines(x=c(0,33), y=c(0,0))	# add line along bottom
# Place the legend at the top-left corner with no frame using given colors
legend(x=0, y=commonYlim-10, c("Foreign forces","Local forces","Insurgents"), cex=1.3, bty="n", fill=clrs)
dev.off()
	
# Pakistan graph/data
qPak <- cbind(qtrLabels$Var1, quarterAgg(pak_forgn, numQuarters), quarterAgg(pak_gov, numQuarters), quarterAgg(pak_insgt, numQuarters))
colnames(qPak) <- c("Label", "PakForgn", "PakGov", "PakInsgt")
write.csv(qPak, "qtrPak.csv", row.names=FALSE)
pdf("qtrPak.pdf", height=6, width=10)
barplot(t(as.matrix(qPak[,2:4])), main="Pakistan violence by actor", cex.main=1.5, cex.lab=1.3, cex=1.2, cex.axis=1.2, ylab="Total number of events", ylim=c(0, commonYlim), names.arg=qPak$Label, beside=T, col=clrs)
lines(x=c(0,33), y=c(0,0))	# add line along bottom
legend(x=0, y=commonYlim-10, c("Foreign forces","Local forces","Insurgents"), cex=1.3, bty="n", fill=clrs)
dev.off()
