# 10 May 2010, generate monthly distributions of Afg/Pak violent events
#	for two categories: civilian & non-civilian
#
##########################################################################
# INSTRUCTIONS: set directories prior to analysis!
setwd('C:/Users/???/ACLEDevents')

afpak<-read.csv("afpak24may10_3actors.csv", as.is = TRUE)
afpak$FREQ <- 1		# used for aggregating events

# INSTRUCTIONS: set directories prior to analysis!
setwd('C:/Users/???/CivilianTrends/')

names(afpak)		# ACHTUNG: ALLY_ACTOR1 vs ALLY_ACTOR_2
length(afpak$EVENT_ID)

# convert text date to a POSIXlt object
	# %Y = year with century, %y = 2 digit year
dates<-strptime(afpak$EVENT_DATE, "%m/%d/%Y")
#summary(dates)

startYr<-2008
startMth<-1
# construct unique monthly id & label
afpak$monthID <- (as.numeric(format(dates, "%Y"))-startYr)*12 + as.numeric(format(dates, "%m"))
afpak$monthLbl <- paste(format(dates, "%b"),format(dates, "%Y"))
#table(afpak$monthLbl)
numMonths<-max(afpak$monthID)

############# identify civilian events
#table(afpak$EVENT_TYPE)
civ_i<-grep("Violence against civilians", afpak$EVENT_TYPE)
civ_evts<-afpak[civ_i,]
length(civ_evts$EVENT_ID)
# mark civilian events
afpak$civ <- 0
afpak$civ[civ_i] <- 1
nonciv_evts<-afpak[afpak$civ==0,]
length(nonciv_evts$EVENT_ID)
print(paste("total events = ", length(afpak$EVENT_ID), sep=""))
print(paste("should equal...", length(civ_evts$EVENT_ID)+length(nonciv_evts$EVENT_ID)), sep="")


############# categorize by country
pak_civ<-civ_evts[civ_evts$COUNTRY=="Pakistan", ]
pak_nonciv<-nonciv_evts[nonciv_evts$COUNTRY=="Pakistan", ]

afg_civ<-civ_evts[civ_evts$COUNTRY=="Afghanistan", ]
afg_nonciv<-nonciv_evts[nonciv_evts$COUNTRY=="Afghanistan", ]

#*********************************************************************************
# function to aggregate events by month
#	requires events$monthID to be set properly
#	requires events$FREQ to be set properly
# 	returns a data frame with the month ID & counts
monthAgg <- function(events, numMnths) {
	# aggregate events, making sure not to skip any 'empty' months!
	mCounts <- numeric(numMnths)
	tmp <- data.frame(aggregate(events$FREQ, list(month = events$monthID), sum))
	mCounts[tmp$month] <- tmp$x
	mCounts <- data.frame(mCounts)
	colnames(mCounts) <- "counts"
	return(mCounts)
}

# Afghanistan data
mnthLabels<-c("Jan 08","Feb 08","Mar 08","Apr 08","May 08","Jun 08","Jul 08","Aug 08","Sep 08","Oct 08","Nov 08","Dec 08","Jan 09","Feb 09","Mar 09","Apr 09","May 09","Jun 09","Jul 09","Aug 09","Sep 09","Oct 09","Nov 09","Dec 09")

mAfg <- cbind(mnthLabels, monthAgg(afg_civ, numMonths), monthAgg(afg_nonciv, numMonths))
colnames(mAfg) <- c("Month", "AfgCiv", "AfgNonCiv")
write.csv(mAfg, "mnthAfg.csv", row.names=FALSE)	# must open in Excel using the import wizard

# Pakistan data
mPak <- cbind(mnthLabels, monthAgg(pak_civ, numMonths), monthAgg(pak_nonciv, numMonths))
colnames(mPak) <- c("Month", "PakCiv", "PakNonCiv")
write.csv(mPak, "mnthPak.csv", row.names=FALSE)

# then make graph in Excel w/ 5th order polynomial

