# 23 Jul 2010, generate quarterly measures of clusters for the combined of Afg/Pak violent events
#	for three categories: foreign forces, local forces, and insurgents
#
##########################################################################
library(spatstat)
library(maptools)
library(rgdal)

# INSTRUCTIONS: set these directories prior to analysis!
baseDir = "C:/Users/.../GIS_Data/"
outDir = "C:/Users/.../AnalysisWikiLeaks/"

# as.is prevents text from being converted to categorical/factor format
events<-read.csv(paste(baseDir, "ACLEDevents/afpak24may10_3actors.csv", sep=""), as.is = TRUE)

# get bounding polygon
border <- readShapePoly(paste(baseDir, "AdminBorders/ESRI_borders/ESRI_AfPakMerge", sep=""), proj4string=CRS("+proj=utm +zone=41 +datum=WGS84"))

# convert shapefile to "observation window" using code from spatstatWorkshop_pn0y.pdf
borderSP <- as(border, "SpatialPolygons")
#summary(borderSP)
borderW <- as(borderSP, "owin")
#summary(borderW)
#plot(borderW)

# convert coords to UTM
SP <- SpatialPoints(cbind(events$LONGITUDE, events$LATITUDE), proj4string=CRS("+proj=longlat"))
UTMcoords <- spTransform(SP, CRS("+proj=utm +zone=41 +datum=WGS84"))
coordsDF <- data.frame(UTMcoords)

pobj <- ppp(coordsDF$coords.x1, coordsDF$coords.x2, window=borderW)
#summary(pobj)

# explore the point distributions
plot(density(pobj, 10000))
#contour(density(pobj, 5000))
plot(pobj)
# cool 3D view with a 10km smoothing bandwidth
persp(density(pobj, 10000))

numQuarters<-max(events$qtrID)
qtrLabels<-data.frame(table(events$qtrLbl))

############# subset 3 actor categories
forgn_evts<-events[events$forgn==1,]
gov_evts<-events[events$localGov==1,]
insgt_evts<-events[events$insgt==1,]

# check actor categories
length(forgn_evts$EVENT_ID)
length(gov_evts$EVENT_ID)
length(insgt_evts$EVENT_ID)
print(paste("total events = ", length(events$EVENT_ID), sep=""))
print(paste("should equal...", length(forgn_evts$EVENT_ID)+length(gov_evts$EVENT_ID)+length(insgt_evts$EVENT_ID), sep=""))

##### INSTRUCTIONS: run 3 times, changing just the actor
actor<-"Foreign Forces"		# 73 seconds
#actor<-"Local Forces"		# 153 seconds
#actor<-"Insurgent"			# 82seconds
startTime <- proc.time()
results <- data.frame(cbind(QtrID=1:8, NumEvents=0, MaxClstDist=0))
for(i in 1:8){
	if (actor == "Foreign Forces") {
		qtrEvents <- forgn_evts[forgn_evts$qtrID == i,]
	} else if (actor == "Local Forces") {
		qtrEvents <- gov_evts[gov_evts$qtrID == i,]
	} else if (actor == "Insurgent") {
		qtrEvents <- insgt_evts[insgt_evts$qtrID == i,]
	} else {
		print(paste("Error, invalid actor", actor))
	}
	results$NumEvents[i] <- length(qtrEvents$qtrID)
	# convert coords to UTM
	SP <- SpatialPoints(cbind(qtrEvents$LONGITUDE, qtrEvents$LATITUDE), proj4string=CRS("+proj=longlat"))
	UTMcoords <- data.frame(spTransform(SP, CRS("+proj=utm +zone=41 +datum=WGS84")))
	pobj <- ppp(UTMcoords$coords.x1, UTMcoords$coords.x2, window=borderW)
	#	'best' edge correction is Ripley isotropic
	edgeCorr <- "best"
	Kin <- Kinhom(pobj, correction=edgeCorr)
#	plot(Kin)
	for(j in 1:length(Kin$iso)){
		if(Kin$iso[j] > Kin$theo[j]) {
			results$MaxClstDist[i] <- Kin$r[j]
		}
	}
}
results

par(mar = c(5, 4, 4, 4) + 0.3)  # Leave space for z axis
plot(results$QtrID, results$MaxClstDist/1000, type='l', xlab="Quarter ID", ylab="Maximum Cluster Distance (km)", main=paste(actor, "Clustering Distances"))
par(new=TRUE)              # key: ask for new plot without erasing old
plot(results$QtrID, results$NumEvents, type='l', col='red', xlab="", yaxt="n", axes=F, ylab="")
axis(side=4, at = pretty(range(results$NumEvents)), col="red", col.axis="red")
mtext("Number of Events", side=4, line=2.2, col="red")

if (actor == "Foreign Forces") {
  	write.csv(results, paste(outDir, "ForeignClust.csv", sep=""))
	savePlot(paste(outDir, "ForeignClust.pdf", sep=""), type="pdf")
} else if (actor == "Local Forces") {
  	write.csv(results, paste(outDir, "LocalClust.csv", sep=""))
	savePlot(paste(outDir, "LocalClust.pdf", sep=""), type="pdf")
} else if (actor == "Insurgent") {
  	write.csv(results, paste(outDir, "InsurgentClust.csv", sep=""))
	savePlot(paste(outDir, "InsurgentClust.pdf", sep=""), type="pdf")
} else {
	print(paste("Error, invalid actor", actor))
}

endTime <- proc.time()
print(paste("elapsed time: ", round(endTime[3]-startTime[3]), " seconds", sep=""))

