# 19 May 2010, explore quarterly FATA district trends of Pak violent events
#		PakFATA, PakNotFATA
#			3 actors for each category
#
##########################################################################
# INSTRUCTIONS: set directory prior to analysis
setwd('C:/Users/???/FATA')
library(foreign)
pak<-read.dbf("EventsFATAJoin.dbf") 

names(pak)
length(pak$EVENT_ID)

# convert text date to a POSIXlt object
	# %Y = year with century, %y = 2 digit year
dates<-strptime(pak$EVENT_DATE, "%m/%d/%Y")
#summary(dates)

qtrLabels<-data.frame(table(pak$qtrLbl))
numQuarters<-max(pak$qtrID)

############# subset 3 actor categories
forgn_evts<-pak[pak$forgn==1,]
gov_evts<-pak[pak$localGov==1,]
insgt_evts<-pak[pak$insgt==1,]

# check actor categories
length(forgn_evts$EVENT_ID)
length(gov_evts$EVENT_ID)
length(insgt_evts$EVENT_ID)
print(paste("total events = ", length(pak$EVENT_ID), sep=""))
print(paste("should equal...", length(forgn_evts$EVENT_ID)+length(gov_evts$EVENT_ID)+length(insgt_evts$EVENT_ID), sep=""))


############### generate FATA/not-FATA data by actor
FATAForgn <- forgn_evts[forgn_evts$Join_Count==1,]
NotFATAForgn <- forgn_evts[forgn_evts$Join_Count==0,]
length(FATAForgn$FREQ)+length(NotFATAForgn$FREQ)
FATAGov <- gov_evts[gov_evts$Join_Count==1,]
NotFATAGov <- gov_evts[gov_evts$Join_Count==0,]
length(FATAGov$FREQ)+length(NotFATAGov$FREQ)
FATAInsgt <- insgt_evts[insgt_evts$Join_Count==1,]
NotFATAInsgt <- insgt_evts[insgt_evts$Join_Count==0,]
length(FATAInsgt$FREQ)+length(NotFATAInsgt$FREQ)


#*********************************************************************************
# function to aggregate events by quarter
#	requires events$qtrID to be set properly
#	requires events$FREQ to be set properly
# 	returns a data frame with the quarter ID & counts
quarterAgg <- function(events, numQtrs) {
	# aggregate events, making sure not to skip any 'empty' months!
	qCounts <- numeric(numQtrs)
	tmp <- data.frame(aggregate(events$FREQ, list(quarter = events$qtrID), sum))
	qCounts[tmp$quarter] <- tmp$x
	qCounts <- data.frame(qCounts)
	colnames(qCounts) <- "counts"
	return(qCounts)
}

# PakFATA, PakNotFATA
country <- "Pakistan"
commonYlim <- 200
clrs<-c("#E64C00FF", "#267300FF", "#6699CDFF")

# FATA
qFATA <- cbind(qtrLabels$Var1, quarterAgg(FATAForgn[FATAForgn$COUNTRY==country, ], numQuarters), quarterAgg(FATAGov[FATAGov$COUNTRY==country, ], numQuarters), quarterAgg(FATAInsgt[FATAInsgt$COUNTRY==country, ], numQuarters))
colnames(qFATA) <- c("Label", paste(substr(country,1,3),"FATAForgn",sep=""), paste(substr(country,1,3),"FATAGov",sep=""), paste(substr(country,1,3),"FATAInsgt",sep=""))
#write.csv(qFATA, paste("qtr",substr(country,1,3),"FATA.csv",sep=""), row.names=FALSE)
pdf(paste("qtr",substr(country,1,3),"FATA.pdf",sep=""), height=6, width=10)
barplot(t(as.matrix(qFATA[,2:4])), main=paste(country," violence within Tribal Areas",sep=""), cex.main=1.5, cex.lab=1.3, cex=1.2, cex.axis=1.2, ylab="Total number of events", ylim=c(0, commonYlim), names.arg=qFATA$Label, beside=T, col=clrs)
lines(x=c(0,33), y=c(0,0))	# add line along bottom
# Place the legend at the top-left corner with no frame 
legend(x=0, y=commonYlim, c("Foreign forces","Local forces","Insurgents"), cex=1.3, bty="n", fill=clrs)
dev.off()

# NotFATA
qNotFATA <- cbind(qtrLabels$Var1, quarterAgg(NotFATAForgn[NotFATAForgn$COUNTRY==country, ], numQuarters), quarterAgg(NotFATAGov[NotFATAGov$COUNTRY==country, ], numQuarters), quarterAgg(NotFATAInsgt[NotFATAInsgt$COUNTRY==country, ], numQuarters))
colnames(qNotFATA) <- c("Label", paste(substr(country,1,3),"NotFATAForgn",sep=""), paste(substr(country,1,3),"NotFATAGov",sep=""), paste(substr(country,1,3),"NotFATAInsgt",sep=""))
#write.csv(qNotFATA, paste("qtr",substr(country,1,3),"NotFATA.csv",sep=""), row.names=FALSE)
pdf(paste("qtr",substr(country,1,3),"NotFATA.pdf",sep=""), height=6, width=10)
barplot(t(as.matrix(qNotFATA[,2:4])), main=paste(country," violence outside Tribal Areas",sep=""), cex.main=1.5, cex.lab=1.3, cex=1.2, cex.axis=1.2, ylab="Total number of events", ylim=c(0, commonYlim), names.arg=qNotFATA$Label, beside=T, col=clrs)
lines(x=c(0,33), y=c(0,0))	# add line along bottom
# Place the legend at the top-left corner with no frame 
legend(x=0, y=commonYlim, c("Foreign forces","Local forces","Insurgents"), cex=1.3, bty="n", fill=clrs)
dev.off()
