# 19 May 2010, explore quarterly border trends of Afg/Pak violent events
#		PakNrBrdr, PakFarBrdr, AfgNrBrdr, AfgFarBrdr
#			3 actors for each category
#
##########################################################################
# INSTRUCTIONS: set directories prior to analysis!
setwd('C:/Users/???/NearBorder')
library(foreign)
afpak<-read.dbf("EventsBorderJoin.dbf") 

names(afpak)
length(afpak$EVENT_ID)

# convert text date to a POSIXlt object
	# %Y = year with century, %y = 2 digit year
dates<-strptime(afpak$EVENT_DATE, "%m/%d/%Y")
#summary(dates)

qtrLabels<-data.frame(table(afpak$qtrLbl))
numQuarters<-max(afpak$qtrID)

############# subset 3 actor categories
forgn_evts<-afpak[afpak$forgn==1,]
gov_evts<-afpak[afpak$localGov==1,]
insgt_evts<-afpak[afpak$insgt==1,]

# check actor categories
length(forgn_evts$EVENT_ID)
length(gov_evts$EVENT_ID)
length(insgt_evts$EVENT_ID)
print(paste("total events = ", length(afpak$EVENT_ID), sep=""))
print(paste("should equal...", length(forgn_evts$EVENT_ID)+length(gov_evts$EVENT_ID)+length(insgt_evts$EVENT_ID), sep=""))


############### generate near/far border data by actor
nearBrdrForgn <- forgn_evts[forgn_evts$Join_Count==1,]
farBrdrForgn <- forgn_evts[forgn_evts$Join_Count==0,]
length(nearBrdrForgn$FREQ)+length(farBrdrForgn$FREQ)
nearBrdrGov <- gov_evts[gov_evts$Join_Count==1,]
farBrdrGov <- gov_evts[gov_evts$Join_Count==0,]
length(nearBrdrGov$FREQ)+length(farBrdrGov$FREQ)
nearBrdrInsgt <- insgt_evts[insgt_evts$Join_Count==1,]
farBrdrInsgt <- insgt_evts[insgt_evts$Join_Count==0,]
length(nearBrdrInsgt$FREQ)+length(farBrdrInsgt$FREQ)


#*********************************************************************************
# function to aggregate events by quarter
#	requires events$qtrID to be set properly
#	requires events$FREQ to be set properly
# 	returns a data frame with the quarter ID & counts
quarterAgg <- function(events, numQtrs) {
	# aggregate events, making sure not to skip any 'empty' months!
	qCounts <- numeric(numQtrs)
	tmp <- data.frame(aggregate(events$FREQ, list(quarter = events$qtrID), sum))
	qCounts[tmp$quarter] <- tmp$x
	qCounts <- data.frame(qCounts)
	colnames(qCounts) <- "counts"
	return(qCounts)
}

# PakNrBrdr, PakFarBrdr, AfgNrBrdr, AfgFarBrdr
# INSTRUCTIONS: run 2x, one for each country
country <- "Afghanistan"
#country <- "Pakistan"

commonYlim <- 250
clrs<-c("#E64C00FF", "#267300FF", "#6699CDFF")
# NearBorder
qNearBrdr <- cbind(qtrLabels$Var1, quarterAgg(nearBrdrForgn[nearBrdrForgn$COUNTRY==country, ], numQuarters), quarterAgg(nearBrdrGov[nearBrdrGov$COUNTRY==country, ], numQuarters), quarterAgg(nearBrdrInsgt[nearBrdrInsgt$COUNTRY==country, ], numQuarters))
colnames(qNearBrdr) <- c("Label", paste(substr(country,1,3),"NearBrdrForgn",sep=""), paste(substr(country,1,3),"NearBrdrGov",sep=""), paste(substr(country,1,3),"NearBrdrInsgt",sep=""))
write.csv(qNearBrdr, paste("qtr",substr(country,1,3),"NearBrdr.csv",sep=""), row.names=FALSE)
pdf(paste("qtr",substr(country,1,3),"NearBrdr.pdf",sep=""), height=6, width=10)
barplot(t(as.matrix(qNearBrdr[,2:4])), main=paste(country," Violence Within 100km of Border",sep=""), cex.main=1.5, cex.lab=1.3, cex=1.2, cex.axis=1.2, ylab="Total Number of Events", ylim=c(0, commonYlim), names.arg=qNearBrdr$Label, beside=T, col=clrs)
lines(x=c(0,33), y=c(0,0))	# add line along bottom
# Place the legend at the top-left corner with no frame 
legend(x=0, y=commonYlim, c("Foreign Forces","Local Forces","Insurgents"), cex=1.3, bty="n", fill=clrs)
dev.off()

# FarBorder
qFarBrdr <- cbind(qtrLabels$Var1, quarterAgg(farBrdrForgn[farBrdrForgn$COUNTRY==country, ], numQuarters), quarterAgg(farBrdrGov[farBrdrGov$COUNTRY==country, ], numQuarters), quarterAgg(farBrdrInsgt[farBrdrInsgt$COUNTRY==country, ], numQuarters))
colnames(qFarBrdr) <- c("Label", paste(substr(country,1,3),"FarBrdrForgn",sep=""), paste(substr(country,1,3),"FarBrdrGov",sep=""), paste(substr(country,1,3),"FarBrdrInsgt",sep=""))
write.csv(qFarBrdr, paste("qtr",substr(country,1,3),"FarBrdr.csv",sep=""), row.names=FALSE)
pdf(paste("qtr",substr(country,1,3),"FarBrdr.pdf",sep=""), height=6, width=10)
barplot(t(as.matrix(qFarBrdr[,2:4])), main=paste(country," Violence Beyond 100km of Border",sep=""), cex.main=1.5, cex.lab=1.3, cex=1.2, cex.axis=1.2, ylab="Total Number of Events", ylim=c(0, commonYlim), names.arg=qFarBrdr$Label, beside=T, col=clrs)
lines(x=c(0,33), y=c(0,0))	# add line along bottom
# Place the legend at the top-left corner with no frame 
legend(x=0, y=commonYlim, c("Foreign Forces","Local Forces","Insurgents"), cex=1.3, bty="n", fill=clrs)
dev.off()
