# 19 May 2010, explore quarterly Pashtun trends for all violent events
#		Pashtun, nonPashtun
#			3 actors for each category
#
##########################################################################
# INSTRUCTIONS: set directories prior to analysis
setwd('C:/Users/???/Pashtun')
library(foreign)
afpak<-read.dbf("EventsPashtunJoin.dbf") 

names(afpak)
length(afpak$EVENT_ID)

# convert text date to a POSIXlt object
	# %Y = year with century, %y = 2 digit year
dates<-strptime(afpak$EVENT_DATE, "%m/%d/%Y")
#summary(dates)

qtrLabels<-data.frame(table(afpak$qtrLbl))
numQuarters<-max(afpak$qtrID)

############# subset 3 actor categories
forgn_evts<-afpak[afpak$forgn==1,]
gov_evts<-afpak[afpak$localGov==1,]
insgt_evts<-afpak[afpak$insgt==1,]

# check actor categories
length(forgn_evts$EVENT_ID)
length(gov_evts$EVENT_ID)
length(insgt_evts$EVENT_ID)
print(paste("total events = ", length(afpak$EVENT_ID), sep=""))
print(paste("should equal...", length(forgn_evts$EVENT_ID)+length(gov_evts$EVENT_ID)+length(insgt_evts$EVENT_ID), sep=""))


############### generate Pashtun/not-Pashtun data by actor
PashtunForgn <- forgn_evts[forgn_evts$Join_Count==1,]
NotPashtunForgn <- forgn_evts[forgn_evts$Join_Count==0,]
length(PashtunForgn$FREQ)+length(NotPashtunForgn$FREQ)
PashtunGov <- gov_evts[gov_evts$Join_Count==1,]
NotPashtunGov <- gov_evts[gov_evts$Join_Count==0,]
length(PashtunGov$FREQ)+length(NotPashtunGov$FREQ)
PashtunInsgt <- insgt_evts[insgt_evts$Join_Count==1,]
NotPashtunInsgt <- insgt_evts[insgt_evts$Join_Count==0,]
length(PashtunInsgt$FREQ)+length(NotPashtunInsgt$FREQ)


#*********************************************************************************
# function to aggregate events by quarter
#	requires events$qtrID to be set properly
#	requires events$FREQ to be set properly
# 	returns a data frame with the quarter ID & counts
quarterAgg <- function(events, numQtrs) {
	# aggregate events, making sure not to skip any 'empty' months!
	qCounts <- numeric(numQtrs)
	tmp <- data.frame(aggregate(events$FREQ, list(quarter = events$qtrID), sum))
	qCounts[tmp$quarter] <- tmp$x
	qCounts <- data.frame(qCounts)
	colnames(qCounts) <- "counts"
	return(qCounts)
}

# Pashtun, NotPashtun
commonYlim <- 300
clrs<-c("#E64C00FF", "#267300FF", "#6699CDFF")

# Pashtun
qPashtun <- cbind(qtrLabels$Var1, quarterAgg(PashtunForgn, numQuarters), quarterAgg(PashtunGov, numQuarters), quarterAgg(PashtunInsgt, numQuarters))
colnames(qPashtun) <- c("Label", paste("PashtunForgn",sep=""), paste("PashtunGov",sep=""), paste("PashtunInsgt",sep=""))
write.csv(qPashtun, paste("qtr","Pashtun.csv",sep=""), row.names=FALSE)
pdf(paste("qtr","Pashtun.pdf",sep=""), height=6, width=10)
barplot(t(as.matrix(qPashtun[,2:4])), main=paste("Violence within Pashtun dominant areas",sep=""), cex.main=1.5, cex.lab=1.3, cex=1.2, cex.axis=1.2, ylab="Total number of events", ylim=c(0, commonYlim), names.arg=qPashtun$Label, beside=T, col=clrs)
lines(x=c(0,33), y=c(0,0))	# add line along bottom
# Place the legend at the top-left corner with no frame 
legend("topleft", c("Foreign forces","Local forces","Insurgents"), cex=1.3, bty="n", fill=clrs)
dev.off()

# NotPashtun
qNotPashtun <- cbind(qtrLabels$Var1, quarterAgg(NotPashtunForgn, numQuarters), quarterAgg(NotPashtunGov, numQuarters), quarterAgg(NotPashtunInsgt, numQuarters))
colnames(qNotPashtun) <- c("Label", paste("NotPashtunForgn",sep=""), paste("NotPashtunGov",sep=""), paste("NotPashtunInsgt",sep=""))
write.csv(qNotPashtun, paste("qtr","NotPashtun.csv",sep=""), row.names=FALSE)
pdf(paste("qtr","NotPashtun.pdf",sep=""), height=6, width=10)
barplot(t(as.matrix(qNotPashtun[,2:4])), main=paste("Violence outside Pashtun dominant areas",sep=""), cex.main=1.5, cex.lab=1.3, cex=1.2, cex.axis=1.2, ylab="Total number of events", ylim=c(0, commonYlim), names.arg=qNotPashtun$Label, beside=T, col=clrs)
lines(x=c(0,33), y=c(0,0))	# add line along bottom
# Place the legend at the top-left corner with no frame 
legend("topleft", c("Foreign forces","Local forces","Insurgents"), cex=1.3, bty="n", fill=clrs)
dev.off()

