# 5 May 2010, explore quarterly slope trends of Afg/Pak violent events
#		use breaks of 4 & 8 degrees
#		output in csv format for making bar graphs
#		PakFlat, PakHilly, PakSteep, AfgFlat, AfgHilly, AfgSteep
#			3 actors for each category
#
##########################################################################
# INSTRUCTIONS: set directories prior to analysis!
#	also set the country variables below
setwd('C:/Users/???/RoughTerrain')

afpak<-read.csv("eventsSlp.csv", as.is = TRUE)

names(afpak)
length(afpak$EVENT_ID)

#hist(afpak$MEAN, main="Mean slope within a 2.5 km radius of each point")
#hist(afpak$COUNT)	# most have 18-20 pixels contributing to the mean slope	

# convert text date to a POSIXlt object
	# %Y = year with century, %y = 2 digit year
dates<-strptime(afpak$EVENT_DATE, "%m/%d/%Y")
#dates<-strptime(afpak$EVENT_DATE, "%m/%d/%y")
summary(dates)

qtrLabels<-data.frame(table(afpak$qtrLbl))
numQuarters<-max(afpak$qtrID)

############# subset 3 actor categories
forgn_evts<-afpak[afpak$forgn==1,]
gov_evts<-afpak[afpak$localGov==1,]
insgt_evts<-afpak[afpak$insgt==1,]

# check actor categories
length(forgn_evts$EVENT_ID)
length(gov_evts$EVENT_ID)
length(insgt_evts$EVENT_ID)
print(paste("total events = ", length(afpak$EVENT_ID), sep=""))
print(paste("should equal...", length(forgn_evts$EVENT_ID)+length(gov_evts$EVENT_ID)+length(insgt_evts$EVENT_ID), sep=""))


#*********************************************************************************
# function to aggregate events by quarter
#	requires events$qtrID to be set properly
#	requires events$FREQ to be set properly
# 	returns a data frame with the quarter ID & counts
quarterAgg <- function(events, numQtrs) {
	# aggregate events, making sure not to skip any 'empty' months!
	qCounts <- numeric(numQtrs)
	tmp <- data.frame(aggregate(events$FREQ, list(quarter = events$qtrID), sum))
	qCounts[tmp$quarter] <- tmp$x
	qCounts <- data.frame(qCounts)
	colnames(qCounts) <- "counts"
	return(qCounts)
}

############### generate monthly aggregations for each slope category
brk1 <- 4
brk2 <- 8
flatForgn <- forgn_evts[forgn_evts$MEAN<brk1,]
hillyForgn <- forgn_evts[forgn_evts$MEAN>=brk1 & forgn_evts$MEAN<brk2,]
steepForgn <- forgn_evts[forgn_evts$MEAN>=brk2,]
length(flatForgn$FREQ)+length(hillyForgn$FREQ)+length(steepForgn$FREQ)
flatGov <- gov_evts[gov_evts$MEAN<brk1,]
hillyGov <- gov_evts[gov_evts$MEAN>=brk1 & gov_evts$MEAN<brk2,]
steepGov <- gov_evts[gov_evts$MEAN>=brk2,]
length(flatGov$FREQ)+length(hillyGov$FREQ)+length(steepGov$FREQ)
flatInsgt <- insgt_evts[insgt_evts$MEAN<brk1,]
hillyInsgt <- insgt_evts[insgt_evts$MEAN>=brk1 & insgt_evts$MEAN<brk2,]
steepInsgt <- insgt_evts[insgt_evts$MEAN>=brk2,]
length(flatInsgt$FREQ)+length(hillyInsgt$FREQ)+length(steepInsgt$FREQ)


# PakFlat, PakHilly, PakSteep, AfgFlat, AfgHilly, AfgSteep
# INSTRUCTIONS: run 2x, one for each country
country <- "Afghanistan"
cntry <- "Afg"
#country <- "Pakistan"
#cntry <- "Pak"

commonYlim <- 200
clrs<-c("#E64C00FF", "#267300FF", "#6699CDFF")
# Flat
qFlat <- cbind(qtrLabels$Var1, quarterAgg(flatForgn[flatForgn$COUNTRY==country, ], numQuarters), quarterAgg(flatGov[flatGov$COUNTRY==country, ], numQuarters), quarterAgg(flatInsgt[flatInsgt$COUNTRY==country, ], numQuarters))
colnames(qFlat) <- c("Label", paste(cntry,"FlatForgn",sep=""), paste(cntry,"FlatGov",sep=""), paste(cntry,"FlatInsgt",sep=""))
write.csv(qFlat, paste("qtr",cntry,"Flat.csv",sep=""), row.names=FALSE)
pdf(paste("qtr",cntry,"Flat.pdf",sep=""), height=6, width=10)
barplot(t(as.matrix(qFlat[,2:4])), main=paste(country," Violence in Flat Terrain",sep=""), cex.main=1.5, cex.lab=1.3, cex=1.2, cex.axis=1.2, ylab="Total Number of Events", ylim=c(0, commonYlim), names.arg=qFlat$Label, beside=T, col=clrs)
lines(x=c(0,33), y=c(0,0))	# add line along bottom
# Place the legend at the top-left corner with no frame 
legend(x=0, y=commonYlim, c("Foreign Forces","Local Forces","Insurgents"), cex=1.3, bty="n", fill=clrs)
dev.off()

# Hilly
qHilly <- cbind(qtrLabels$Var1, quarterAgg(hillyForgn[hillyForgn$COUNTRY==country, ], numQuarters), quarterAgg(hillyGov[hillyGov$COUNTRY==country, ], numQuarters), quarterAgg(hillyInsgt[hillyInsgt$COUNTRY==country, ], numQuarters))
colnames(qHilly) <- c("Label", paste(cntry,"HillyForgn",sep=""), paste(cntry,"HillyGov",sep=""), paste(cntry,"HillyInsgt",sep=""))
write.csv(qHilly, paste("qtr",cntry,"Hilly.csv",sep=""), row.names=FALSE)
pdf(paste("qtr",cntry,"Hilly.pdf",sep=""), height=6, width=10)
barplot(t(as.matrix(qHilly[,2:4])), main=paste(country," Violence in Hilly Terrain",sep=""), cex.main=1.5, cex.lab=1.3, cex=1.2, cex.axis=1.2, ylab="Total Number of Events", ylim=c(0, commonYlim), names.arg=qHilly$Label, beside=T, col=clrs)
lines(x=c(0,33), y=c(0,0))	# add line along bottom
# Place the legend at the top-left corner with no frame 
legend(x=0, y=commonYlim, c("Foreign Forces","Local Forces","Insurgents"), cex=1.3, bty="n", fill=clrs)
dev.off()

# Steep
qSteep <- cbind(qtrLabels$Var1, quarterAgg(steepForgn[steepForgn$COUNTRY==country, ], numQuarters), quarterAgg(steepGov[steepGov$COUNTRY==country, ], numQuarters), quarterAgg(steepInsgt[steepInsgt$COUNTRY==country, ], numQuarters))
colnames(qSteep) <- c("Label", paste(cntry,"SteepForgn",sep=""), paste(cntry,"SteepGov",sep=""), paste(cntry,"SteepInsgt",sep=""))
write.csv(qSteep, paste("qtr",cntry,"Steep.csv",sep=""), row.names=FALSE)
pdf(paste("qtr",cntry,"Steep.pdf",sep=""), height=6, width=10)
barplot(t(as.matrix(qSteep[,2:4])), main=paste(country," Violence in Steep Terrain",sep=""), cex.main=1.5, cex.lab=1.3, cex=1.2, cex.axis=1.2, ylab="Total Number of Events", ylim=c(0, commonYlim), names.arg=qSteep$Label, beside=T, col=clrs)
lines(x=c(0,33), y=c(0,0))	# add line along bottom
# Place the legend at the top-left corner with no frame 
legend(x=0, y=commonYlim, c("Foreign Forces","Local Forces","Insurgents"), cex=1.3, bty="n", fill=clrs)
dev.off()
